@@ -68,6 +68,72 @@ def return_value_on_exception(value, exception):
     return decorator
 
 
+def global_config(fun=None, **config_kw):
+    """
+    Applies a certain global configuration to the function on which it acts.
+    By default, if no arguments are entered, it will use native_types=True, query_exceptions=False.
+
+    Example
+    -------
+
+    from jsonutils.functions.decorators import global_config
+    from jsonutils import JSONObject
+
+    data = JSONObject(
+        [
+            {
+                "A": 1,
+                "B": 2
+            },
+            {
+                "A": 1,
+                "B": 3
+            },
+        ]
+    )
+
+    @global_config
+    def query_1(data):
+        return data.get(A=1)
+
+    >>> query_1(data)   # this will use native_types=True, query_exceptions=False
+        1               # so, this is a python `int`, not a JSONInt
+
+    @global_config(query_exceptions=True)
+    def query_2(data):
+        return data.get(A=1)
+
+    >>> query_2(data)   # now this user query_exceptions=True, so it will throw a multiple values exception.
+        JSONQueryMultipleValues: More than one value returned by query
+    """
+
+    if not config_kw:
+        config_kw = dict(native_types=True, query_exceptions=False)
+
+    def _set_config(dic):
+        for k, v in dic.items():
+            setattr(config, k, v)
+
+    INITIAL_CONFIG = {k: getattr(config, k) for k in config_kw}
+
+    def decorator(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            _set_config(config_kw)
+            try:
+                result = func(*args, **kwargs)
+            finally:
+                _set_config(INITIAL_CONFIG)
+            return result
+
+        return wrapper
+
+    if fun is not None:
+        return decorator(fun)
+
+    return decorator
+
+
 def return_native_types(func):
     """ """
 
@@ -79,28 +145,3 @@ def return_native_types(func):
         return res
 
     return wrapper
-
-
-def easy_queries(func):
-    """
-    When applied on a function, it will use native_types and no exceptions in queries
-    """
-
-    INITIAL_CONFIG = {
-        "native_types": config.native_types,
-        "query_exceptions": config.query_exceptions,
-    }
-
-    @wraps(func)
-    def wrapper(*args, **kwargs):
-        config.native_types = True
-        config.query_exceptions = False
-
-        try:
-            result = func(*args, **kwargs)
-        finally:
-            config.native_types = INITIAL_CONFIG["native_types"]
-            config.query_exceptions = INITIAL_CONFIG["query_exceptions"]
-        return result
-
-    return wrapper
